##  Reporting Missing Data
If certain items relevant to your organization are missing from the catalog, you can request that they be added. Our research team will assess the feasibility of including these items. The process to report missing data varies depending on the data type.
### Business Capabilities
Business capabilities in the reference catalog are based on the SAP reference architecture, providing best-practice business capability maps for various industries. If certain items relevant for your organization are missing, [submit a product idea![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Froadmap.leanix.net%2Ftabs%2F10-on-roadmap%2Fsubmit-idea "https://roadmap.leanix.net/tabs/10-on-roadmap/submit-idea") to share your use case.
### Applications
Before creating a request, review which applications are in scope and out of scope in [Applications in the Reference Catalog](https://help.sap.com/docs/leanix/ea/applications-in-reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD "By using reference data for application fact sheets, you can increase standardization and data quality, as well as set relations to other fact sheets for best-practice modeling."). If certain applications relevant for your use case are missing from the catalog, you can request their addition. To learn more about how our research team prioritizes requests, see [Provider Tiers and Response Times](https://help.sap.com/docs/leanix/ea/reference-catalog-provider-tiers-response-times-and-faqs?locale=en-US&state=PRODUCTION&version=CLOUD#loio275acd507a44101487b7e1bb7246de11__provider_tiers_and_response_times).
  * If a certain application type is not within the catalog’s scope, [submit a product idea![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Froadmap.leanix.net%2Ftabs%2F10-on-roadmap%2Fsubmit-idea "https://roadmap.leanix.net/tabs/10-on-roadmap/submit-idea") to share your use case.
  * If a specific application is missing, [submit a ticket![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.leanix.net%2Fsupport "https://www.leanix.net/support") to SAP LeanIX Support. If you're an SAP customer, submit a request from the [SAP for Me![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fme.sap.com%2F "https://me.sap.com/") portal.


### IT Components
Before creating a request, review which IT components are in scope and out of scope in [IT Components in the Reference Catalog](https://help.sap.com/docs/leanix/ea/it-components-in-reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD "By using reference data for IT component fact sheets, you can increase standardization and data quality, set relations to other fact sheets for best-practice modeling, as well as manage technology obsolescence risks by using vendor lifecycle information."). If certain IT components relevant for your use case are missing from the catalog, you can request their addition. To learn more about how our research team prioritizes requests, see [Provider Tiers and Response Times](https://help.sap.com/docs/leanix/ea/reference-catalog-provider-tiers-response-times-and-faqs?locale=en-US&state=PRODUCTION&version=CLOUD#loio275acd507a44101487b7e1bb7246de11__provider_tiers_and_response_times).
  * If a certain IT component type is not within the catalog’s scope, [submit a product idea![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Froadmap.leanix.net%2Ftabs%2F10-on-roadmap%2Fsubmit-idea "https://roadmap.leanix.net/tabs/10-on-roadmap/submit-idea") to share your use case.
  * If a specific IT component is missing, you can submit a request from the reference catalog page (for multiple items) or the fact sheet linking page (for a single item) using the Report Missing Data option. For detailed information, see [Report Missing Data in Catalog Items](https://help.sap.com/docs/leanix/ea/it-components-in-reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD#loio275adf737a44101482dccd5ff2ab307e__report_missing_data_in_catalog_items). To avoid missing any updates regarding the research status, make sure that your notifications are enabled. If our research team requests additional information, provide it through the corresponding missing request form. Do not submit it in comments, as our research team will not receive this information.
